@@ -1,24 +1,21 @@
-
-
-
-#' Most Police Don’t Live In The Cities They Serve
+#' Most Police Don't Live In The Cities They Serve
 #'
 #' The raw data behind the story
-#' "Most Police Don’t Live In The Cities They Serve"
+#' "Most Police Don't Live In The Cities They Serve"
 #' \url{http://fivethirtyeight.com/datalab/most-police-dont-live-in-the-cities-they-serve/}.
-#' 
+#'
 #' @details
 #' The dataset includes the cities with the 75 largest police forces, with the exception of Honolulu for which data is not available. All calculations are based on data from the U.S. Census.
-#' 
+#'
 #' The Census Bureau numbers are potentially going to differ from other counts for three reasons:
 #' \enumerate{
-#'    \item The census category for police officers also includes sheriffs, transit police and others who might not be under the same jurisdiction as a city’s police department proper. The census category won’t include private security officers.
+#'    \item The census category for police officers also includes sheriffs, transit police and others who might not be under the same jurisdiction as a city's police department proper. The census category won't include private security officers.
 #'    \item The census data is estimated from 2006 to 2010; police forces may have changed in size since then.
 #'    \item There is always a margin of error in census numbers; they are estimates, not complete counts.
 #' }
-#' 
+#'
 #' Note: Missing values means that there are fewer than 100 police officers of that race serving that city.
-#' 
+#'
 #' @format A data frame with 75 rows representing cities and 8 variables:
 #' \describe{
 #'   \item{city}{U.S. city}
@@ -31,6 +28,12 @@
 #'   \item{asian}{Percentage of Asian police officers who live in the city}
 #' }
 #' @source See \url{https://github.com/fivethirtyeight/data/tree/master/police-locals}
+#'
+#' @examples
+#' # To convert data frame to tidy data (long) format, run:
+#' library(tidyverse)
+#' police_locals_tidy <- police_locals %>%
+#'    gather(key = "race", value = "perc_in", all:asian)
 "police_locals"
 
 #' Looking For Clues: Who Is Going To Run For President In 2016?
@@ -158,7 +161,7 @@
 #' The Rock Isn't Alone: Lots Of People Are Worried About 'The Big One'
 #'
 #' The raw data behind the story
-#' "The Rock Isn’t Alone: Lots Of People Are Worried About 'The Big One'"
+#' "The Rock Isn't Alone: Lots Of People Are Worried About 'The Big One'"
 #' \url{http://fivethirtyeight.com/datalab/the-rock-isnt-alone-lots-of-people-are-worried-about-the-big-one/}.
 #'
 #' @format A data frame with 1013 rows representing respondents and 11 variables:
@@ -191,13 +194,13 @@
 #'   \item{lottery_a}{not sure}
 #'   \item{smoke}{Is respondent a smoker?}
 #'   \item{alcohol}{Is respondent a drinker?}
-#'   \item{gamble}{Is respondent a gambler?} 
+#'   \item{gamble}{Is respondent a gambler?}
 #'   \item{skydiving}{Is respondent a skydiver?}
 #'   \item{speed}{not sure}
 #'   \item{cheated}{not sure}
 #'   \item{steak}{not sure}
 #'   \item{steak_prep}{Preferred steak preparation}
-#'   \item{female}{Is respondent female?} 
+#'   \item{female}{Is respondent female?}
 #'   \item{age}{Age}
 #'   \item{hhold_income}{Household income}
 #'   \item{educ}{Education level}
@@ -284,21 +287,24 @@
 #' The raw data behind the story
 #' "How Trump Hacked The Media"
 #' \url{http://fivethirtyeight.com/features/how-donald-trump-hacked-the-media/}.
-#' 
+#'
 #' @format A data frame with 286 rows representing lead stories and 3 variables:
 #' \describe{
 #'   \item{date}{Date of lead story about Donald Trump.}
 #'   \item{major_cat}{Story classification}
 #'   \item{detail}{}
 #' }
-#' @source Memeorandum \url{http://www.memeorandum.com/}.  See \url{memeorandum}
+#' @source Memeorandum \url{http://www.memeorandum.com/}.
 "trump_news"
 
 
-#' Donald Trump twitter
+#' The World's Favorite Donald Trump Tweets
 #'
+#' The raw data behind the story
+#' "The World's Favorite Donald Trump Tweets"
+#' \url{https://fivethirtyeight.com/features/the-worlds-favorite-donald-trump-tweets/}.
 #' Tweets posted on twitter by Donald Trump (@@realDonaldTrump)
-#' 
+#'
 #' @format A data frame with 448 rows representing tweets and 3 variables:
 #' \describe{
 #'   \item{id}{}
@@ -326,8 +332,8 @@
 #' @source Social Security Administration \url{https://www.ssa.gov/oact/babynames/limits.html}.  See \url{https://github.com/fivethirtyeight/data/tree/master/unisex-names}.
 "unisex_names"
 
-	
-	
+
+
 #' Where People Go To Check The Weather
 #'
 #' The raw data behind the story
@@ -349,5 +355,36 @@
 #' @source The source of the data is a Survey Monkey Audience poll commissioned by FiveThirtyEight and conducted from April 6 to April 10, 2015.  See \url{https://github.com/fivethirtyeight/data/tree/master/weather-check}
 "weather_check"
 
+#' Can You Rule Riddler Nation?
+#'
+#' The raw data behind the story
+#' "Can You Rule Riddler Nation?"
+#' \url{https://fivethirtyeight.com/features/can-you-rule-riddler-nation/}.
+#' Analysis of the submitted solutions can be found at: \url{https://fivethirtyeight.com/features/can-you-save-the-drowning-swimmer/}
+#'
+#' @format A data frame with 1387 rows representing submissions and 11 variables:
+#' \describe{
+#'   \item{castle1}{Number of troops out of 100 send to castle 1}
+#'   \item{castle2}{Number of troops out of 100 send to castle 2}
+#'   \item{castle3}{Number of troops out of 100 send to castle 3}
+#'   \item{castle4}{Number of troops out of 100 send to castle 4}
+#'   \item{castle5}{Number of troops out of 100 send to castle 5}
+#'   \item{castle6}{Number of troops out of 100 send to castle 6}
+#'   \item{castle7}{Number of troops out of 100 send to castle 7}
+#'   \item{castle8}{Number of troops out of 100 send to castle 8}
+#'   \item{castle9}{Number of troops out of 100 send to castle 9}
+#'   \item{castle10}{Number of troops out of 100 send to castle 10}
+#'   \item{reason}{Why did you choose your troop deployment?}
+#' }
+#' @source See \url{https://github.com/fivethirtyeight/data/tree/master/riddler-castles}
+#'
+#' @examples
+#' # To convert data frame to tidy data (long) format, run
+#' library(tidyverse)
+#' library(stringr)
+#' riddler_castles_tidy<-riddler_castles %>%
+#'    gather(key = castle , value = soldiers, castle1:castle10) %>%
+#'    mutate(castle = as.numeric(str_replace(castle, "castle","")))
+"riddler_castles"
 
 
